Transform a N-dimensional array a to vector. The transformation is done
assuming that the last index of the array moves fastest. For instance, an array
\(a\) of dimensions (2,2,2) will produce the vector
\(v = (a_{111}, a_{112}, a_{113}, a_{121}, a_{122},\ldots,a_{333})\).
Usage
Array2Vector(arr)
Value
A vector filled with the data of the input array arr.