Learn R Programming

mipfp (version 3.2.3)

GetLinInd: Extracting the linearly independant columns from a matrix

Description

Extracts the linearly dependant columns of matrix to obtain a matrix of full rank using QR decomposition.

Usage

GetLinInd(mat, tol = 1e-10)

Value

A list containing the new matrix and the index of the selected colums.

mat.li

A matrix made of the linearly independant columns of mat.

idx

The index of the selected columns.

Arguments

mat

The matrix possibly containing linearly dependant columns

tol

Rank estimation tolerance. Default is \(1e^{-10}\).

Author

Johan Barthelemy

Maintainer: Johan Barthelemy johan@uow.edu.au.

References

Golub, G. H., Van Loan C. F. (2012) Matrix Computations. Third Edition. Johns Hopkins University Press.

See Also

Examples

Run this code
# generation of a matrix with linearly dependant columns
A <- matrix(c(1, 2, 3,
              1, 2, 4,
              1, 2, 8), nrow = 3, ncol = 3, byrow = TRUE)
              
# extracting and printing the linearly independant columns
B <- GetLinInd(A)
print(B)

Run the code above in your browser using DataLab