Learn R Programming

mipfp (version 3.2.3)

spnamur: Synthetic population of Namur (Belgium)

Description

This data drame contains a synthetic population of individuals for Belgian city of Namur. The attributes details the gender, age class, socio-professional status, education level and driving license ownership of every synthetic individual.

Usage

data(spnamur)

Arguments

Format

A data frame detailing the synthetic individuals whose columns are described in the Table below.

AttributeValues (levels)
Household.typeC (couple); F (family with children); I (isolated); N (non family)
GenderF (female); H (male)
Prof.statusA (active); E (student); I (inactive)
Education.levelO (none); P (primary); S (high school); U (higher education)
Driving.licenseO (no); P (yes)
Age.class0 (0-5); 1 (6-17); 2 (18-39); 3 (40-59); 4 (60+)

References

Barthelemy, J. and Toint, P.L. (2013) Synthetic population generation without a sample Transportation Science 47 (2): 266-279

Examples

Run this code
data(spnamur)
# generating the contingency table of the synthetic population
table(spnamur)

Run the code above in your browser using DataLab